import os
import shutil
from vex import exceptions


def obviously_not_a_virtualenv(path):
    include = os.path.join(path, 'include')
    bin = os.path.join(path, 'bin')
    scripts = os.path.join(path, 'Scripts')
    if not os.path.exists(bin) or os.path.exists(scripts):
        return True
    if not os.path.exists(include):
        return True
    if not any(filename.startswith('py') for filename in os.listdir(include)):
        return True
    return False


def handle_remove(ve_path):
    if not os.path.exists(ve_path):
        return
    if hasattr(os, "geteuid"):
        if os.geteuid() == 0 or os.environ.get('USER', '') == 'root':
            raise exceptions.VirtualenvNotRemoved(
                "not removing any directory as root user")
    if ve_path in ("/", "\\"):
        raise exceptions.VirtualenvNotRemoved(
            "not removing possible root directory {0!r}".format(ve_path))
    if ve_path == os.path.expanduser("~"):
        raise exceptions.VirtualenvNotRemoved(
            "not removing possible home directory {0!r}".format(ve_path))
    # last-minute checks
    if obviously_not_a_virtualenv(ve_path):
        raise exceptions.VirtualenvNotRemoved(
            "path {0!r} did not look like a virtualenv".format(ve_path))
    print("Removing {0!r}".format(ve_path))
    shutil.rmtree(ve_path)



from setuptools import setup

with open('README.rst', 'r') as inp:
    long_description = inp.read()

setup(
    name="vex",
    version="0.0.11",
    author="Sasha Hart",
    author_email="s@sashahart.net",
    url="http://github.com/sashahart/vex",
    description="Run commands in a virtualenv",
    license="MIT",
    long_description=long_description,
    keywords="virtualenv virtualenvwrapper workon installation deployment",
    install_requires=['virtualenv'],
    packages=['vex'],
    package_data={'vex': ['shell_configs/*']},
    scripts=['scripts/vex'],
    entry_points = {
        'console_scripts': ['vex = vex.main:main'],
    },
    classifiers=[
        "Topic :: Utilities",
        "Topic :: Software Development",
        "Topic :: System :: Shells",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Development Status :: 3 - Alpha",
        "Operating System :: POSIX",
        "Operating System :: POSIX :: Linux",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: PyPy",
    ]
)
